@@ -76,14 +76,17 @@ test_that("extra_args contains default arguments", {
 })
 
 test_that("Task creation works via constructor and sf object", {
+  skip_if_not_installed("sf")
   data_sf = sf::st_as_sf(ecuador, coords = c("x", "y"))
 
   # create mlr3 task
   expect_error(TaskClassifST$new("ecuador_sf",
-    backend = data_sf, target = "slides", positive = "TRUE"))
+    backend = data_sf, target = "slides", positive = "TRUE"
+  ))
 })
 
 test_that("Task creation works via constructor and sf object", {
+  skip_if_not_installed("sf")
   data = test_make_sp()
   data$p_1 = c(rep("A", 18), rep("B", 18))
   data$response = rnorm(36)
